pub struct CellFlag { /* private fields */ }Implementations
Sourceimpl CellFlag
impl CellFlag
pub const REAL: CellFlag
pub const SIGNED: CellFlag
Sourcepub fn from_bits(bits: u32) -> Option<CellFlag>
pub fn from_bits(bits: u32) -> Option<CellFlag>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> CellFlag
pub const fn from_bits_truncate(bits: u32) -> CellFlag
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> CellFlag
pub const unsafe fn from_bits_unchecked(bits: u32) -> CellFlag
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: CellFlag) -> bool
pub const fn intersects(&self, other: CellFlag) -> bool
Returns true if there are flags common to both self and other.